/*
 * Copyright 2020 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.compose.material.icons.rounded

import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.materialIcon
import androidx.compose.material.icons.materialPath
import androidx.compose.ui.graphics.vector.VectorAsset

val Icons.Rounded.BluetoothConnected: VectorAsset
    get() {
        if (icon != null) return icon!!
        icon = materialIcon {
            materialPath {
                moveTo(6.0f, 13.0f)
                curveToRelative(0.55f, -0.55f, 0.55f, -1.44f, 0.0f, -1.99f)
                lineTo(6.0f, 11.0f)
                curveToRelative(-0.55f, -0.55f, -1.45f, -0.55f, -2.0f, 0.0f)
                reflectiveCurveToRelative(-0.55f, 1.45f, 0.0f, 2.0f)
                reflectiveCurveToRelative(1.45f, 0.55f, 2.0f, 0.0f)
                close()
                moveTo(20.0f, 11.0f)
                curveToRelative(-0.56f, -0.56f, -1.45f, -0.56f, -2.0f, -0.01f)
                lineTo(18.0f, 11.0f)
                curveToRelative(-0.55f, 0.55f, -0.55f, 1.44f, 0.0f, 1.99f)
                lineTo(18.0f, 13.0f)
                curveToRelative(0.55f, 0.55f, 1.44f, 0.55f, 1.99f, 0.0f)
                lineTo(20.0f, 13.0f)
                curveToRelative(0.55f, -0.55f, 0.55f, -1.45f, 0.0f, -2.0f)
                close()
                moveTo(17.0f, 7.0f)
                lineToRelative(-4.29f, -4.29f)
                curveToRelative(-0.63f, -0.63f, -1.71f, -0.19f, -1.71f, 0.7f)
                verticalLineToRelative(6.18f)
                lineTo(7.11f, 5.7f)
                curveToRelative(-0.39f, -0.39f, -1.02f, -0.39f, -1.41f, 0.0f)
                curveToRelative(-0.39f, 0.39f, -0.39f, 1.02f, 0.0f, 1.41f)
                lineTo(10.59f, 12.0f)
                lineTo(5.7f, 16.89f)
                curveToRelative(-0.39f, 0.39f, -0.39f, 1.02f, 0.0f, 1.41f)
                curveToRelative(0.39f, 0.39f, 1.02f, 0.39f, 1.41f, 0.0f)
                lineTo(11.0f, 14.41f)
                verticalLineToRelative(6.18f)
                curveToRelative(0.0f, 0.89f, 1.08f, 1.34f, 1.71f, 0.71f)
                lineTo(17.0f, 17.0f)
                curveToRelative(0.39f, -0.39f, 0.39f, -1.02f, 0.0f, -1.42f)
                lineTo(13.41f, 12.0f)
                lineTo(17.0f, 8.42f)
                curveToRelative(0.39f, -0.39f, 0.39f, -1.03f, 0.0f, -1.42f)
                close()
                moveTo(14.88f, 16.29f)
                lineTo(13.0f, 18.17f)
                verticalLineToRelative(-3.76f)
                lineToRelative(1.88f, 1.88f)
                close()
                moveTo(13.0f, 9.59f)
                lineTo(13.0f, 5.83f)
                lineToRelative(1.88f, 1.88f)
                lineTo(13.0f, 9.59f)
                close()
            }
        }
        return icon!!
    }

private var icon: VectorAsset? = null
