/*
 * Copyright 2020 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.compose.material.icons.rounded

import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.materialIcon
import androidx.compose.material.icons.materialPath
import androidx.compose.ui.graphics.vector.VectorAsset

val Icons.Rounded.NotListedLocation: VectorAsset
    get() {
        if (icon != null) return icon!!
        icon = materialIcon {
            materialPath {
                moveTo(12.0f, 2.0f)
                curveToRelative(-4.2f, 0.0f, -8.0f, 3.22f, -8.0f, 8.2f)
                curveToRelative(0.0f, 3.18f, 2.45f, 6.92f, 7.34f, 11.23f)
                curveToRelative(0.38f, 0.33f, 0.95f, 0.33f, 1.33f, 0.0f)
                curveTo(17.55f, 17.12f, 20.0f, 13.38f, 20.0f, 10.2f)
                curveTo(20.0f, 5.22f, 16.2f, 2.0f, 12.0f, 2.0f)
                moveTo(12.71f, 15.7f)
                curveTo(12.52f, 15.9f, 12.28f, 16.0f, 12.0f, 16.0f)
                curveToRelative(-0.27f, 0.0f, -0.53f, -0.11f, -0.71f, -0.3f)
                curveToRelative(-0.19f, -0.19f, -0.3f, -0.44f, -0.29f, -0.71f)
                curveToRelative(-0.01f, -0.55f, 0.43f, -0.99f, 0.98f, -1.0f)
                curveToRelative(0.01f, 0.0f, 0.01f, 0.0f, 0.02f, 0.0f)
                curveToRelative(0.55f, -0.01f, 0.99f, 0.43f, 1.0f, 0.98f)
                curveToRelative(0.0f, 0.01f, 0.0f, 0.01f, 0.0f, 0.02f)
                curveTo(13.0f, 15.27f, 12.9f, 15.51f, 12.71f, 15.7f)
                moveTo(14.69f, 9.91f)
                curveToRelative(-0.21f, 0.35f, -0.48f, 0.71f, -0.89f, 1.09f)
                curveToRelative(-0.32f, 0.3f, -0.53f, 0.56f, -0.65f, 0.77f)
                curveToRelative(-0.1f, 0.19f, -0.16f, 0.49f, -0.16f, 0.69f)
                verticalLineToRelative(0.07f)
                curveTo(12.98f, 12.8f, 12.75f, 13.0f, 12.48f, 13.0f)
                horizontalLineToRelative(-0.85f)
                curveToRelative(-0.28f, 0.0f, -0.5f, -0.22f, -0.5f, -0.5f)
                verticalLineToRelative(-0.16f)
                curveToRelative(0.0f, -0.45f, 0.1f, -0.84f, 0.29f, -1.16f)
                curveToRelative(0.19f, -0.33f, 0.52f, -0.7f, 1.0f, -1.12f)
                curveToRelative(0.28f, -0.25f, 0.48f, -0.47f, 0.61f, -0.66f)
                reflectiveCurveToRelative(0.19f, -0.4f, 0.19f, -0.64f)
                curveToRelative(0.0f, -0.29f, -0.11f, -0.54f, -0.32f, -0.74f)
                curveToRelative(-0.22f, -0.2f, -0.5f, -0.3f, -0.85f, -0.3f)
                curveToRelative(-0.37f, 0.0f, -0.74f, 0.1f, -0.96f, 0.3f)
                curveToRelative(-0.12f, 0.12f, -0.21f, 0.23f, -0.29f, 0.38f)
                curveToRelative(-0.03f, 0.07f, -0.08f, 0.21f, -0.09f, 0.26f)
                curveTo(10.66f, 8.83f, 10.47f, 9.0f, 10.24f, 9.0f)
                horizontalLineTo(9.55f)
                curveToRelative(-0.26f, 0.0f, -0.47f, -0.19f, -0.5f, -0.45f)
                curveToRelative(-0.01f, -0.08f, 0.0f, -0.16f, 0.02f, -0.24f)
                curveToRelative(0.18f, -0.72f, 0.52f, -1.16f, 0.9f, -1.52f)
                curveTo(10.53f, 6.29f, 11.25f, 6.0f, 12.0f, 6.0f)
                curveToRelative(0.59f, 0.0f, 1.11f, 0.12f, 1.57f, 0.35f)
                reflectiveCurveToRelative(0.79f, 0.55f, 1.05f, 0.96f)
                curveTo(14.87f, 7.72f, 15.0f, 8.16f, 15.0f, 8.66f)
                curveTo(15.0f, 9.15f, 14.89f, 9.56f, 14.69f, 9.91f)
            }
        }
        return icon!!
    }

private var icon: VectorAsset? = null
