/*
 * Copyright 2020 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.compose.material.icons.rounded

import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.materialIcon
import androidx.compose.material.icons.materialPath
import androidx.compose.ui.graphics.vector.VectorAsset

val Icons.Rounded.SettingsRemote: VectorAsset
    get() {
        if (icon != null) return icon!!
        icon = materialIcon {
            materialPath {
                moveTo(15.0f, 9.0f)
                lineTo(9.0f, 9.0f)
                curveToRelative(-0.55f, 0.0f, -1.0f, 0.45f, -1.0f, 1.0f)
                verticalLineToRelative(12.0f)
                curveToRelative(0.0f, 0.55f, 0.45f, 1.0f, 1.0f, 1.0f)
                horizontalLineToRelative(6.0f)
                curveToRelative(0.55f, 0.0f, 1.0f, -0.45f, 1.0f, -1.0f)
                lineTo(16.0f, 10.0f)
                curveToRelative(0.0f, -0.55f, -0.45f, -1.0f, -1.0f, -1.0f)
                close()
                moveTo(12.0f, 15.0f)
                curveToRelative(-1.1f, 0.0f, -2.0f, -0.9f, -2.0f, -2.0f)
                reflectiveCurveToRelative(0.9f, -2.0f, 2.0f, -2.0f)
                reflectiveCurveToRelative(2.0f, 0.9f, 2.0f, 2.0f)
                reflectiveCurveToRelative(-0.9f, 2.0f, -2.0f, 2.0f)
                close()
                moveTo(7.82f, 6.82f)
                curveToRelative(0.35f, 0.35f, 0.9f, 0.38f, 1.3f, 0.1f)
                curveTo(9.93f, 6.34f, 10.93f, 6.0f, 12.0f, 6.0f)
                reflectiveCurveToRelative(2.07f, 0.34f, 2.88f, 0.91f)
                curveToRelative(0.4f, 0.28f, 0.95f, 0.26f, 1.3f, -0.09f)
                curveToRelative(0.43f, -0.43f, 0.39f, -1.14f, -0.09f, -1.5f)
                curveTo(14.94f, 4.49f, 13.53f, 4.0f, 12.0f, 4.0f)
                reflectiveCurveToRelative(-2.94f, 0.49f, -4.09f, 1.32f)
                curveToRelative(-0.49f, 0.35f, -0.52f, 1.07f, -0.09f, 1.5f)
                close()
                moveTo(12.0f, 0.0f)
                curveTo(9.36f, 0.0f, 6.94f, 0.93f, 5.05f, 2.47f)
                curveToRelative(-0.46f, 0.38f, -0.5f, 1.07f, -0.08f, 1.49f)
                curveToRelative(0.36f, 0.36f, 0.93f, 0.39f, 1.32f, 0.07f)
                curveTo(7.84f, 2.77f, 9.83f, 2.0f, 12.0f, 2.0f)
                reflectiveCurveToRelative(4.16f, 0.77f, 5.7f, 2.04f)
                curveToRelative(0.39f, 0.32f, 0.96f, 0.29f, 1.32f, -0.07f)
                curveToRelative(0.42f, -0.42f, 0.38f, -1.11f, -0.08f, -1.49f)
                curveTo(17.06f, 0.93f, 14.64f, 0.0f, 12.0f, 0.0f)
                close()
            }
        }
        return icon!!
    }

private var icon: VectorAsset? = null
