/*
 * Copyright 2020 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.compose.material.icons.twotone

import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.materialIcon
import androidx.compose.material.icons.materialPath
import androidx.compose.ui.graphics.vector.VectorAsset

val Icons.TwoTone.Brightness2: VectorAsset
    get() {
        if (icon != null) return icon!!
        icon = materialIcon {
            materialPath(fillAlpha = 0.3f, strokeAlpha = 0.3f) {
                moveTo(18.0f, 12.0f)
                curveToRelative(0.0f, -4.41f, -3.59f, -8.0f, -8.0f, -8.0f)
                curveToRelative(-0.34f, 0.0f, -0.68f, 0.02f, -1.01f, 0.07f)
                curveTo(10.9f, 6.23f, 12.0f, 9.05f, 12.0f, 12.0f)
                curveToRelative(0.0f, 2.95f, -1.1f, 5.77f, -3.01f, 7.93f)
                curveToRelative(0.33f, 0.05f, 0.67f, 0.07f, 1.01f, 0.07f)
                curveToRelative(4.41f, 0.0f, 8.0f, -3.59f, 8.0f, -8.0f)
                close()
            }
            materialPath {
                moveTo(5.0f, 20.65f)
                curveTo(6.47f, 21.5f, 8.18f, 22.0f, 10.0f, 22.0f)
                curveToRelative(5.52f, 0.0f, 10.0f, -4.48f, 10.0f, -10.0f)
                reflectiveCurveTo(15.52f, 2.0f, 10.0f, 2.0f)
                curveToRelative(-1.82f, 0.0f, -3.53f, 0.5f, -5.0f, 1.35f)
                curveTo(7.99f, 5.08f, 10.0f, 8.3f, 10.0f, 12.0f)
                reflectiveCurveToRelative(-2.01f, 6.92f, -5.0f, 8.65f)
                close()
                moveTo(12.0f, 12.0f)
                curveToRelative(0.0f, -2.95f, -1.1f, -5.77f, -3.01f, -7.93f)
                curveTo(9.32f, 4.02f, 9.66f, 4.0f, 10.0f, 4.0f)
                curveToRelative(4.41f, 0.0f, 8.0f, 3.59f, 8.0f, 8.0f)
                reflectiveCurveToRelative(-3.59f, 8.0f, -8.0f, 8.0f)
                curveToRelative(-0.34f, 0.0f, -0.68f, -0.02f, -1.01f, -0.07f)
                curveTo(10.9f, 17.77f, 12.0f, 14.95f, 12.0f, 12.0f)
                close()
            }
        }
        return icon!!
    }

private var icon: VectorAsset? = null
