/*
 * Copyright 2020 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.compose.material.icons.twotone

import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.materialIcon
import androidx.compose.material.icons.materialPath
import androidx.compose.ui.graphics.vector.VectorAsset

val Icons.TwoTone.ChildFriendly: VectorAsset
    get() {
        if (icon != null) return icon!!
        icon = materialIcon {
            materialPath(fillAlpha = 0.3f, strokeAlpha = 0.3f) {
                moveTo(15.0f, 4.34f)
                verticalLineTo(8.0f)
                horizontalLineToRelative(3.66f)
                curveTo(18.05f, 6.3f, 16.7f, 4.95f, 15.0f, 4.34f)
                close()
                moveTo(8.04f, 14.36f)
                lineToRelative(0.44f, 0.67f)
                curveToRelative(1.19f, 0.16f, 2.19f, 0.92f, 2.68f, 1.97f)
                horizontalLineToRelative(2.68f)
                curveToRelative(0.56f, -1.18f, 1.77f, -2.0f, 3.16f, -2.0f)
                curveToRelative(0.15f, 0.0f, 0.31f, 0.01f, 0.46f, 0.03f)
                lineToRelative(0.29f, -0.37f)
                curveToRelative(0.4f, -0.51f, 0.7f, -1.07f, 0.92f, -1.66f)
                horizontalLineTo(7.37f)
                curveToRelative(0.32f, 0.67f, 0.57f, 1.19f, 0.67f, 1.36f)
                close()
            }
            materialPath {
                moveTo(13.0f, 2.0f)
                verticalLineToRelative(8.0f)
                horizontalLineToRelative(8.0f)
                curveToRelative(0.0f, -4.42f, -3.58f, -8.0f, -8.0f, -8.0f)
                close()
                moveTo(15.0f, 8.0f)
                lineTo(15.0f, 4.34f)
                curveToRelative(1.7f, 0.6f, 3.05f, 1.95f, 3.66f, 3.66f)
                lineTo(15.0f, 8.0f)
                close()
                moveTo(6.44f, 11.0f)
                lineToRelative(-0.95f, -2.0f)
                lineTo(2.0f, 9.0f)
                verticalLineToRelative(2.0f)
                horizontalLineToRelative(2.22f)
                reflectiveCurveToRelative(1.89f, 4.07f, 2.12f, 4.42f)
                curveToRelative(-1.1f, 0.59f, -1.84f, 1.75f, -1.84f, 3.08f)
                curveTo(4.5f, 20.43f, 6.07f, 22.0f, 8.0f, 22.0f)
                curveToRelative(1.76f, 0.0f, 3.22f, -1.3f, 3.46f, -3.0f)
                horizontalLineToRelative(2.08f)
                curveToRelative(0.24f, 1.7f, 1.7f, 3.0f, 3.46f, 3.0f)
                curveToRelative(1.93f, 0.0f, 3.5f, -1.57f, 3.5f, -3.5f)
                curveToRelative(0.0f, -1.04f, -0.46f, -1.97f, -1.18f, -2.61f)
                curveTo(20.37f, 14.54f, 21.0f, 12.84f, 21.0f, 11.0f)
                lineTo(6.44f, 11.0f)
                close()
                moveTo(8.0f, 20.0f)
                curveToRelative(-0.83f, 0.0f, -1.5f, -0.67f, -1.5f, -1.5f)
                reflectiveCurveTo(7.17f, 17.0f, 8.0f, 17.0f)
                reflectiveCurveToRelative(1.5f, 0.67f, 1.5f, 1.5f)
                reflectiveCurveTo(8.83f, 20.0f, 8.0f, 20.0f)
                close()
                moveTo(17.0f, 20.0f)
                curveToRelative(-0.83f, 0.0f, -1.5f, -0.67f, -1.5f, -1.5f)
                reflectiveCurveTo(16.17f, 17.0f, 17.0f, 17.0f)
                reflectiveCurveToRelative(1.5f, 0.67f, 1.5f, 1.5f)
                reflectiveCurveTo(17.83f, 20.0f, 17.0f, 20.0f)
                close()
                moveTo(17.74f, 14.66f)
                lineToRelative(-0.29f, 0.37f)
                curveToRelative(-0.14f, -0.02f, -0.3f, -0.03f, -0.45f, -0.03f)
                curveToRelative(-1.39f, 0.0f, -2.6f, 0.82f, -3.16f, 2.0f)
                horizontalLineToRelative(-2.68f)
                curveToRelative(-0.5f, -1.04f, -1.5f, -1.8f, -2.68f, -1.97f)
                lineToRelative(-0.44f, -0.67f)
                curveToRelative(-0.1f, -0.17f, -0.34f, -0.69f, -0.67f, -1.36f)
                horizontalLineToRelative(11.29f)
                curveToRelative(-0.21f, 0.59f, -0.52f, 1.15f, -0.92f, 1.66f)
                close()
            }
        }
        return icon!!
    }

private var icon: VectorAsset? = null
